@@ -5,7 +5,7 @@ use strict;
 use warnings;
 use utf8;
 
-our $VERSION = 1.118;
+our $VERSION = 1.119;
 
 use Scalar::Util ();
 use Hash::Util ();
@@ -944,7 +944,11 @@ sub isLocked {
         local $@;
         # Ohne $r gibt es eine Warning
         my $r = eval {$self->{'this_key_does_not_exist'}};
-        return $@? 1: 0;
+        if ($@) {
+            return 1;
+        }
+        delete $self->{'this_key_does_not_exist'};
+        return 0;
     }
 
     return Hash::Util::hashref_unlocked($self)? 0: 1;
@@ -1317,7 +1321,7 @@ Das Benchmark-Programm (bench-hash):
 
 =head1 VERSION
 
-1.118
+1.119
 
 =head1 AUTHOR
 
