@@ -5,9 +5,8 @@ use strict;
 use warnings;
 use utf8;
 
-our $VERSION = 1.118;
+our $VERSION = 1.119;
 
-use Prty::ClassLoader;
 use Test::Builder ();
 use Prty::Option;
 use Prty::Path;
@@ -405,8 +404,9 @@ sub testPath {
         # reduzieren zu t.
         $path =~ s|^\w+/test|t|;
     }
-    elsif (my $dir = '.cotedo/root/file') {
+    else {
         # Übler Hack. FIXME: Beheben.
+        my $dir = '.cotedo/root/file'; 
         $path = "$dir/$path";
     }
 
@@ -1078,7 +1078,7 @@ sub MODIFY_CODE_ATTRIBUTES {
 
 =head1 VERSION
 
-1.118
+1.119
 
 =head1 AUTHOR
 
